import { Auth } from '../service/index.js';
import cors from 'cors';
import express from 'express';
import { AssistantPath } from '../util/index.js';
export class Middleware {
    static register(app) {
        const limit = '64mb';
        app.use(cors());
        app.use(express.json({ limit }));
        app.use(this.auth());
        app.use(express.urlencoded({ extended: false, limit }));
        try {
            const resizedImagePath = AssistantPath.getResizedImagePath();
            if (resizedImagePath) {
                app.use('/api/image', express.static(resizedImagePath));
            }
        }
        catch (error) {
            console.error(error.message);
        }
    }
    static isPublicRoute(route) {
        return Middleware.publicRoutes.some((publicRoute) => route.includes(publicRoute));
    }
    static auth() {
        return async (req, res, next) => {
            if (Middleware.isPublicRoute(req.path)) {
                return next();
            }
            const { authorization = '' } = req.headers;
            const basicAuthValidation = await Auth.isValidBasicAuth(authorization);
            if (basicAuthValidation.authorized) {
                return next();
            }
            const tokenValidation = await Auth.isValidBearerAuth(authorization);
            if (tokenValidation.authorized) {
                return next();
            }
            res.status(401).send({
                message: 'UNAUTHORIZED',
                data: {
                    BasicAuth: basicAuthValidation.reason,
                    Token: tokenValidation.reason,
                },
            });
        };
    }
}
Middleware.publicRoutes = [
    '/api/version',
    '/api/image',
    '/access/token',
    '/access/refresh-token',
    '/api/updater-approved-version',
    '/update',
    '/api/testConnection',
    '/report',
];
