import crypto from 'node:crypto';
class Crypt {
    constructor() {
        this.ivSize = 16;
        this.keySize = 32;
        this.textSize = 32;
        this.algorithm = 'aes-256-cbc';
    }
    padText(text, size, options) {
        const { from = 'binary', to = 'hex' } = options || {};
        if (!text.length || text.length % size) {
            return Buffer.concat([
                Buffer.from(text, from),
                Buffer.alloc(size - (text.length % size), 0),
            ]).toString(to);
        }
        return Buffer.from(text, from).toString(to);
    }
    b64ToBin(str) {
        return Buffer.from(str, 'base64').toString('binary');
    }
    hexToDec(value) {
        return parseInt(value, 16);
    }
    decToHex(value) {
        return value.toString(16);
    }
    substr(str, start, size) {
        return str.substring(start, start + size);
    }
    strReplace(str, replacement, start, length) {
        const firstPart = str.substring(0, start);
        const secondPart = str.substring(start + length);
        return firstPart + replacement + secondPart;
    }
    encodeEncryptedText(textToEncode, iv) {
        let ivPos = Math.floor(Math.random() * 15) + 1;
        let text = this.strReplace(textToEncode, iv, ivPos, 0);
        ivPos = this.decToHex(ivPos);
        text = this.strReplace(text, ivPos, 0, 0);
        text = Buffer.from(text, 'binary').toString('base64');
        return text;
    }
    encrypt(textToEncrypt, key) {
        const iv = crypto.randomBytes(16);
        const text = Buffer.from(this.padText(textToEncrypt, this.textSize), 'hex').toString('utf-8');
        const parsedKey = key ? Buffer.from(key, 'utf-8').toString('binary') : '';
        const encodedKey = this.padText(parsedKey, this.keySize);
        const cipher = crypto.createCipheriv(this.algorithm, Buffer.from(encodedKey, 'hex'), iv);
        cipher.setAutoPadding(false);
        let encrypted = cipher.update(text);
        encrypted = Buffer.concat([encrypted, cipher.final()]);
        const encryptedData = encrypted.toString('binary');
        return this.encodeEncryptedText(encryptedData, iv.toString('binary'));
    }
    decodeEncryptedText(textToDecode) {
        let text = Buffer.from(textToDecode, 'base64').toString('binary');
        const ivPos = this.hexToDec(text[0]) + 1;
        let iv = this.substr(text, ivPos, this.ivSize);
        const textArr = text.split(iv);
        textArr[0] = textArr[0].substring(1);
        text = textArr.join('');
        iv = this.padText(iv, this.ivSize);
        return { text, iv };
    }
    decrypt(text, key) {
        const parsedKey = key ? Buffer.from(key, 'utf-8').toString('binary') : '';
        const encodedKey = this.padText(parsedKey, this.keySize);
        const { iv: decodedIv, text: decodedText } = this.decodeEncryptedText(text);
        const decipher = crypto.createDecipheriv(this.algorithm, Buffer.from(encodedKey, 'hex'), Buffer.from(decodedIv, 'hex'));
        decipher.setAutoPadding(false);
        let decrypted = decipher.update(Buffer.from(decodedText, 'binary'));
        decrypted = Buffer.concat([decrypted, decipher.final()]);
        return decrypted.toString('utf8');
    }
}
const instance = new Crypt();
export { instance as Crypt };
